@@ -6,53 +6,53 @@
 #' individual facets. You can use it to fine-tune limits, breaks and other scale
 #' parameters for individual facets, provided the facet allows free scales.
 #'
-#' @param x,y A \code{list} wherein elements are either x/y position scales or
-#'   \code{NULL}s. Alternatively, a list of formulae (see details).
+#' @param x,y A `list` wherein elements are either x/y position scales or
+#'   `NULL`s. Alternatively, a list of formulae (see details).
 #'
 #' @export
 #'
 #' @details It is intended that this function works with both
-#'   \code{\link[ggplot2]{facet_wrap}} and \code{\link[ggplot2]{facet_grid}}.
-#'   For \code{facet_wrap}, the scales are used for each individual panel. For
-#'   \code{facet_grid}, the scales are used for the rows and columns. Note that
-#'   these facets must be used with \code{scales = "free"} or \code{"free_x"} or
-#'   \code{"free_y"}, depending on what scales are added.
+#'   [ggplot2::facet_wrap()] and [ggplot2::facet_grid()].
+#'   For `facet_wrap`, the scales are used for each individual panel. For
+#'   `facet_grid`, the scales are used for the rows and columns. Note that
+#'   these facets must be used with `scales = "free"` or `"free_x"` or
+#'   `"free_y"`, depending on what scales are added.
 #'
 #'   Axis titles are derived from the first scale in the list (or the default
-#'   position scale when the first list element is \code{NULL}).
+#'   position scale when the first list element is `NULL`).
 #'
 #'   \subsection{Scale transformations}{It is allowed to use individual scale
 #'   transformations for facets, but this functionality comes with the trade-off
-#'   that the out of bounds (\code{oob}) argument for individual scales is
+#'   that the out of bounds (`oob`) argument for individual scales is
 #'   ignored. Values that are out of bounds will be clipped. Whereas the
-#'   \code{stat} part of a ggplot layer is typically calculated after scale
-#'   transformations, the calculation of the \code{stat} happens before scale
+#'   `stat` part of a ggplot layer is typically calculated after scale
+#'   transformations, the calculation of the `stat` happens before scale
 #'   transformation with this function, which can lead to some awkward results.
 #'   The suggested workaround is to pre-transform the data for layers with
-#'   non-identity \code{stat} parts.}
+#'   non-identity `stat` parts.}
 #'
-#'   \subsection{Scale list input}{\code{NULL}s are valid list elements and
+#'   \subsection{Scale list input}{`NULL`s are valid list elements and
 #'   signal that the default position scale should be used at the position in
-#'   the list where the \code{NULL} occurs. Since transformations are applied
+#'   the list where the `NULL` occurs. Since transformations are applied
 #'   before facet scales are initiated, it is not recommended to use a default
 #'   position (either the first in the list, or defined outside
-#'   \code{facetted_pos_scales()}) scale with a transformation other than
-#'   \code{trans = "identity"} (the default).}
+#'   `facetted_pos_scales()`) scale with a transformation other than
+#'   `trans = "identity"` (the default).}
 #'
-#'   \subsection{Formula list input}{The \code{x} and \code{y} arguments also
+#'   \subsection{Formula list input}{The `x` and `y` arguments also
 #'   accept a list of two-sided formulas. The left hand side of a formula should
-#'   evaluate to a \code{logical} vector. The right hand side of the formula
-#'   should evaluate to a position scale, wherein the \code{x} argument accepts
-#'   x-position scales and the \code{y} argument accepts y-position scales.
+#'   evaluate to a `logical` vector. The right hand side of the formula
+#'   should evaluate to a position scale, wherein the `x` argument accepts
+#'   x-position scales and the `y` argument accepts y-position scales.
 #'   Notably, the left hand side of the formula is evaluated using the tidy
-#'   evaluation framework, whereby the \code{data.frame} with the plot's layout
+#'   evaluation framework, whereby the `data.frame` with the plot's layout
 #'   is given priority over the environment in which the formula was created. As
 #'   a consequence, variables (columns) that define faceting groups can be
 #'   references directly.}
 #'
-#' @seealso \code{\link[ggplot2]{scale_continuous}} and \code{scale_x_discrete}.
+#' @seealso [ggplot2::scale_x_continuous()] and `scale_x_discrete`.
 #'
-#' @return A \emph{facetted_pos_scales} object, instructing a ggplot how to
+#' @return A *facetted_pos_scales* object, instructing a ggplot how to
 #'   adjust the scales per facet.
 #'
 #' @examples
@@ -311,13 +311,14 @@ train_scales_individual <- function(x_scales, y_scales, layout, data, params, se
 
 #' @keywords internal
 finish_data_individual <- function(data, layout, x_scales, y_scales, params) {
+
   # Divide data by panel
-  panels <- split(data, data$PANEL, drop = FALSE)
-  panels <- lapply(names(panels), function(i) {
-    dat  <- panels[[i]]
+  idx    <- vec_group_loc(data$PANEL)$loc
+  panels <- vec_chop(data, idx)
+  panels <- lapply(panels, function(dat) {
 
     # Match panel to their scales
-    panel_id <- match(as.numeric(i), layout$PANEL)
+    panel_id <- match(as.numeric(dat$PANEL[[1]]), layout$PANEL)
     xidx <- layout[panel_id, "SCALE_X"]
     yidx <- layout[panel_id, "SCALE_Y"]
 
@@ -334,9 +335,7 @@ finish_data_individual <- function(data, layout, x_scales, y_scales, params) {
     }
     dat
   })
-
-  # Recombine the data
-  data <- unsplit(panels, data$PANEL)
+  data <- vec_unchop(panels, idx)
   data
 }
 
